package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.GetQuestionInfoDTO;
import com.diagbot.dto.ModuleInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.ModuleInfoFacade;
import com.diagbot.vo.AddModuleInfoVO;
import com.diagbot.vo.GetModuleInfoVO;
import com.diagbot.vo.ModuleGetQuestionInfoVO;
import com.diagbot.vo.UpdateModuleInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 模型表 前端控制器
 * </p>
 *
 * @author zhoutg
 * @since 2018-12-05
 */
@RestController
@RequestMapping("/moduleInfo")
@SuppressWarnings("unchecked")
@Api(value = "主诉-既往史模板相关API", tags = { "主诉-既往史模板相关API" })
public class ModuleInfoController {


    @Autowired
    ModuleInfoFacade moduleInfoFacade;

    @ApiOperation(value = "模板新增[by:wangyu]",
            notes = "name: 模板名称，必填<br>" +
                    "type: 模板类型，必填<br>" +
                    "questionId: 标签id，必填<br>" +
                    "flag: 特殊标示类型")
    @PostMapping("/saveModuleInfo")
    @SysLogger("saveModuleInfo")
    @Transactional
    public RespDTO<Boolean> saveModuleInfo(@Valid @RequestBody AddModuleInfoVO addModuleInfoVO) {
        Boolean data = moduleInfoFacade.saveModuleInfo(addModuleInfoVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "模板修改[by:wangyu]",
            notes = "id: 模板id，必填<br>" +
                    "name: 模板名称，必填<br>" +
                    "type: 模板类型，必填<br>" +
                    "questionId: 标签id，必填<br>" +
                    "flag: 特殊标示类型")
    @PostMapping("/updateModuleInfo")
    @SysLogger("updateModuleInfo")
    @Transactional
    public RespDTO<Boolean> updateModuleInfo(@Valid @RequestBody UpdateModuleInfoVO updateModuleInfoVO) {
        Boolean data = moduleInfoFacade.updateModuleInfo(updateModuleInfoVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "模板删除[by:zhoutg]",
            notes = "")
    @PostMapping("/delete")
    @SysLogger("delete")
    @Transactional
    public RespDTO<Boolean> delete(String ids) {
        moduleInfoFacade.deleteByIdsFac(ids);
        return RespDTO.onSuc(true);
    }

    @ApiOperation(value = "获取标签池信息[by:wangyu]",
            notes = "tagName: 标签名<br>" +
                    "moduleId: 模板id，添加时不用填，修改时必填<br>")
    @PostMapping("/getQuestionInfos")
    @SysLogger("getQuestionInfos")
    public RespDTO<List<GetQuestionInfoDTO>> getQuestionInfos(@Valid @RequestBody ModuleGetQuestionInfoVO moduleGetQuestionInfoVO) {
        List<GetQuestionInfoDTO> date = moduleInfoFacade.getQuestionInfos(moduleGetQuestionInfoVO);
        return RespDTO.onSuc(date);
    }

    @ApiOperation(value = "获取子模板信息[by:wangyu]",
            notes = "type: 模板类型,1：主诉模板 2：现病史模板 3：现病史空模板 4 : 其他史模板 5：嵌套模板 6：慢病模板<br>" +
                    "<br>")
    @PostMapping("/getModuleInfo")
    @SysLogger("getModuleInfo")
    public RespDTO<List<ModuleInfoDTO>> getModuleInfo(@Valid @RequestBody GetModuleInfoVO getModuleInfoVO) {
        List<ModuleInfoDTO> date = moduleInfoFacade.getModuleInfo(getModuleInfoVO);
        return RespDTO.onSuc(date);
    }
}
